@@ -1,5 +1,4 @@
 //go:build tinygo.riscv
-// +build tinygo.riscv
 
 package runtime
 
@@ -7,6 +6,12 @@ import "device/riscv"
 
 const deferExtraRegs = 0
 
+// RISC-V has a maximum alignment of 16 bytes (both for RV32 and for RV64).
+// Source: https://riscv.org/wp-content/uploads/2015/01/riscv-calling.pdf
+func align(ptr uintptr) uintptr {
+	return (ptr + 15) &^ 15
+}
+
 func getCurrentStackPointer() uintptr {
 	return uintptr(stacksave())
 }
