@@ -27,23 +27,24 @@ func GOROOT() string {
 
 // Copy size bytes from src to dst. The memory areas must not overlap.
 // This function is implemented by the compiler as a call to a LLVM intrinsic
-// like llvm.memcpy.p0i8.p0i8.i32(dst, src, size, false).
+// like llvm.memcpy.p0.p0.i32(dst, src, size, false).
 func memcpy(dst, src unsafe.Pointer, size uintptr)
 
 // Copy size bytes from src to dst. The memory areas may overlap and will do the
 // correct thing.
 // This function is implemented by the compiler as a call to a LLVM intrinsic
-// like llvm.memmove.p0i8.p0i8.i32(dst, src, size, false).
+// like llvm.memmove.p0.p0.i32(dst, src, size, false).
 func memmove(dst, src unsafe.Pointer, size uintptr)
 
 // Set the given number of bytes to zero.
 // This function is implemented by the compiler as a call to a LLVM intrinsic
-// like llvm.memset.p0i8.i32(ptr, 0, size, false).
+// like llvm.memset.p0.i32(ptr, 0, size, false).
 func memzero(ptr unsafe.Pointer, size uintptr)
 
 // This intrinsic returns the current stack pointer.
 // It is normally used together with llvm.stackrestore but also works to get the
 // current stack pointer in a platform-independent way.
+//
 //export llvm.stacksave
 func stacksave() unsafe.Pointer
 
@@ -70,6 +71,7 @@ func nanotime() int64 {
 }
 
 // Copied from the Go runtime source code.
+//
 //go:linkname os_sigpipe os.sigpipe
 func os_sigpipe() {
 	runtimePanic("too many writes on closed pipe")
@@ -85,3 +87,20 @@ func LockOSThread() {
 // Stub for now
 func UnlockOSThread() {
 }
+
+func KeepAlive(x interface{}) {
+	// Unimplemented. Only required with SetFinalizer().
+}
+
+func SetFinalizer(obj interface{}, finalizer interface{}) {
+	// Unimplemented.
+}
+
+var godebugUpdate func(string, string)
+
+//go:linkname godebug_setUpdate internal/godebug.setUpdate
+func godebug_setUpdate(update func(string, string)) {
+	// The 'update' function needs to be called whenever the GODEBUG environment
+	// variable changes (for example, via os.Setenv).
+	godebugUpdate = update
+}
