@@ -1,5 +1,4 @@
 //go:build k210
-// +build k210
 
 // This file implements target-specific things for the K210 chip as used in the
 // MAix Bit with Mic.
@@ -104,7 +103,7 @@ func initPeripherals() {
 	// Enable FPIOA peripheral.
 	kendryte.SYSCTL.CLK_EN_PERI.SetBits(kendryte.SYSCTL_CLK_EN_PERI_FPIOA_CLK_EN)
 
-	machine.Serial.Configure(machine.UARTConfig{})
+	machine.InitSerial()
 }
 
 func putchar(c byte) {
